pub enum CoreError {
Show 14 variants
InvalidCredentials,
Unauthenticated,
Forbidden,
NotFound,
Conflict(String),
BadRequest(String),
NotInitialized,
AlreadyInitialized,
Protocol {
code: ProtocolError,
description: String,
},
Store(StoreError),
Password,
Jwt,
Internal,
ConfigError(String),
}Variants
InvalidCredentials
Unauthenticated
Forbidden
NotFound
Conflict(String)
BadRequest(String)
NotInitialized
AlreadyInitialized
Protocol
Store(StoreError)
Password
Jwt
Internal
ConfigError(String)
Emitted during process initialisation when a required configuration value is invalid. Causes a fast startup abort with a clear message.
Implementations